@@ -44,6 +44,7 @@ import org.hsqldb.lib.Set;
 import org.hsqldb.lib.SimpleLog;
 import org.hsqldb.lib.java.JavaSystem;
 import org.hsqldb.store.ValuePool;
+import org.hsqldb.lib.StringUtil;
 
 /**
  * Manages a .properties file for a database.
@@ -54,6 +55,78 @@ import org.hsqldb.store.ValuePool;
  */
 public class HsqlDatabaseProperties extends HsqlProperties {
 
+    private static String hsqldb_method_class_names =
+        "hsqldb.method_class_names";
+    private static HashSet accessibleJavaMethodNames;
+
+    static {
+        try {
+            String prop = System.getProperty(hsqldb_method_class_names);
+
+            if (prop != null) {
+                accessibleJavaMethodNames = new HashSet();
+
+                String[] names = StringUtil.split(prop, ";");
+
+                for (int i = 0; i < names.length; i++) {
+                    accessibleJavaMethodNames.add(names[i]);
+                }
+            }
+        } catch (Exception e) {}
+    }
+
+    /**
+     * If the system property "hsqldb.method_class_names" is not set, then
+     * static methods of all available Java classes can be accessed as functions
+     * in HSQLDB. If the property is set, then only the list of semicolon
+     * seperated method names becomes accessible. An empty property value means
+     * no class is accessible.<p>
+     *
+     * A property value that ends with .* is treated as a wild card and allows
+     * access to all classe or method names formed by substitution of the
+     * asterisk.<p>
+     *
+     * All methods of org.hsqldb.Library and java.lang.Math are always
+     * accessible.
+     *
+     *
+     */
+    public static boolean supportsJavaMethod(String name) {
+
+        if (accessibleJavaMethodNames == null) {
+            return true;
+        }
+
+        if (name.startsWith("org.hsqldb.Library.")) {
+            return true;
+        }
+
+        if (name.startsWith("java.lang.Math.")) {
+            return true;
+        }
+
+        if (accessibleJavaMethodNames.contains(name)) {
+            return true;
+        }
+
+        Iterator it = accessibleJavaMethodNames.iterator();
+
+        while (it.hasNext()) {
+            String className = (String) it.next();
+            int    limit     = className.lastIndexOf(".*");
+
+            if (limit < 1) {
+                continue;
+            }
+
+            if (name.startsWith(className.substring(0, limit + 1))) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
     // column number mappings
     public static final int indexName         = 0;
     public static final int indexAccess       = 1;
@@ -86,7 +159,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
     public static final String VERSION_STRING_1_8_0     = "1.8.0";
     public static final String FIRST_COMPATIBLE_VERSION = "1.8.0";
     public static final String THIS_VERSION             = "1.8.0";
-    public static final String THIS_FULL_VERSION        = "1.8.0.8";
+    public static final String THIS_FULL_VERSION        = "1.8.0.9";
     public static final String THIS_CACHE_VERSION       = "1.7.0";
     public static final String PRODUCT_NAME = "HSQL Database Engine";
     public static final int    MAJOR                    = 1,
@@ -197,8 +270,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
             0, 1, 2
         }));
         meta.put(hsqldb_cache_file_scale,
-                 getMeta(hsqldb_cache_file_scale, SET_PROPERTY, 1,
-                         new byte[] {
+                 getMeta(hsqldb_cache_file_scale, SET_PROPERTY, 1, new byte[] {
             1, 8
         }));
         meta.put(hsqldb_script_format,
@@ -364,8 +436,8 @@ public class HsqlDatabaseProperties extends HsqlProperties {
         try {
             exists = super.load();
         } catch (Exception e) {
-            throw Trace.error(Trace.FILE_IO_ERROR,
-                              Trace.LOAD_SAVE_PROPERTIES, new Object[] {
+            throw Trace.error(Trace.FILE_IO_ERROR, Trace.LOAD_SAVE_PROPERTIES,
+                              new Object[] {
                 fileName, e
             });
         }
@@ -381,7 +453,9 @@ public class HsqlDatabaseProperties extends HsqlProperties {
         // do not open if the database belongs to a later (future) version
         int check = version.substring(0, 5).compareTo(THIS_VERSION);
 
-        Trace.check(check <= 0, Trace.WRONG_DATABASE_FILE_VERSION);
+        if (check > 0) {
+            throw Trace.error(Trace.WRONG_DATABASE_FILE_VERSION);
+        }
 
         version = getProperty(db_version);
 
@@ -435,8 +509,8 @@ public class HsqlDatabaseProperties extends HsqlProperties {
         } catch (Exception e) {
             database.logger.appLog.logContext(SimpleLog.LOG_ERROR, "failed");
 
-            throw Trace.error(Trace.FILE_IO_ERROR,
-                              Trace.LOAD_SAVE_PROPERTIES, new Object[] {
+            throw Trace.error(Trace.FILE_IO_ERROR, Trace.LOAD_SAVE_PROPERTIES,
+                              new Object[] {
                 fileName, e
             });
         }
